@@ -41,7 +41,7 @@ class SmartDriver(SeleniumDriverCore):
         return self.driver.get_screenshot_as_base64()
 
 
-    def _classify(self, element_name):
+    def _classify(self, element_name, is_backup=False):
         msg = ''
         if self.test_case_creation_mode:
             self._test_case_upload_screenshot(element_name)
