@@ -137,7 +137,7 @@ class SmartDriver(SeleniumDriverCore):
                 real_offset = resp_data['page_offset'] / self.multiplier
                 if real_offset > bottom_page_offset or real_offset < current_offset:
                     scroll_offset = int(real_offset - current_offset)
-                    ActionChains(self.driver).scroll_by_amount(0, scroll_offset).perform()
+                    self._scroll_page(scroll_offset)
 
                     sleep(1)
                     screenshotBase64 = self._get_screenshot()
@@ -203,7 +203,7 @@ class SmartDriver(SeleniumDriverCore):
             return element, run_key, msg
 
     def _classify_full_screen(self, element_name):
-        ActionChains(self.driver).scroll_by_amount(0, -100000).perform() # go to the top
+        self._scroll_page(-100000) # go to the top
         last_offset = -1
         offset = 1
         responses = []
@@ -221,7 +221,7 @@ class SmartDriver(SeleniumDriverCore):
             r = requests.post(classify_url, json=data, verify=False).json()
             if r['success']:
                 return r
-            ActionChains(self.driver).scroll_by_amount(0, int(window_height)).perform()
+            self._scroll_page(window_height)
             sleep(0.2)
             offset = self.driver.execute_script('return window.pageYOffset')
         return r
@@ -361,8 +361,8 @@ class ai_elem(webdriver.remote.webelement.WebElement):
     def tag_name(self):
         return self._tag_name
 
-    def click(self, js_click=False):
-        if self._is_real_elem == True:
+    def click(self, js_click=False, use_cdp=False):
+        if self._is_real_elem == True and use_cdp == False:
             if not js_click:
                 webdriver.remote.webelement.WebElement.click(self)
             else:
