@@ -15,7 +15,6 @@ from distutils.util import strtobool
 from PIL import Image
 from packaging import version
 import selenium
-from selenium.webdriver.common.action_chains import ActionChains
 
 if version.parse(selenium.__version__) < version.parse('4.0.0'):
     old_selenium = True
@@ -63,8 +62,12 @@ class SeleniumDriverCore(object):
         self.url = initialization_options.get('server_url',
                 os.environ.get('DEVTOOLSAI_URL', 'https://smartdriver.dev-tools.ai'))
         self.default_prod_url = 'https://smartdriver.dev-tools.ai'
+        try:
+            # TODO(etienne): This doesn't work on Appium.
+            self.scanner = Scanner(self, self.driver, self.url, self.api_key)
+        except Exception:
+            self.scanner = None
 
-        self.scanner = Scanner(self, self.driver, self.url, self.api_key)
         test_case_name = initialization_options.get('test_case_name', None)
         if test_case_name is None:
             test_case_name = traceback.format_stack()[0].split()[1].split('/')[-1].split('.py')[0]
@@ -511,6 +514,14 @@ class SeleniumDriverCore(object):
                 log.error('error in check_frozen')
         return resp.get('is_frozen', True)
 
+    def _scroll_page(self, amount):
+        self.driver.execute_script('window.scrollBy(0, ' + str(int(amount)) + ')')
+
+    def _scroll_to_element(self, element, scroll_up=False):
+        if scroll_up:
+            self.driver.execute_script('arguments[0].scrollIntoView(false);', element)
+        else:
+            self.driver.execute_script('arguments[0].scrollIntoView(true);', element)
 
     def _upload_screenshot_if_necessary(self, element_name, driver_element=None):
         if self._check_frozen(element_name):
@@ -526,13 +537,11 @@ class SeleniumDriverCore(object):
             if needs_to_scroll:
                 self.previous_page_offset = self.page_offset
                 self.ref_screenshot_uuid = screenshot_uuid
-                ActionChains(self.driver) \
-                    .scroll_to_element(driver_element) \
-                    .perform()
+                self._scroll_to_element(driver_element, driver_element.rect['y'] < self.page_offset)
                 screenshotBase64 = self._get_screenshot()
                 screenshot_uuid = self.get_screenshot_hash(screenshotBase64)
                 self.page_offset = self.driver.execute_script('return window.pageYOffset')
-                ActionChains(self.driver).scroll_by_amount(0, int(self.previous_page_offset - self.page_offset)).perform()
+                self._scroll_page(int(self.previous_page_offset - self.page_offset)) # scroll back to initial position
 
         # Check results
         try:
@@ -596,7 +605,7 @@ class SeleniumDriverCore(object):
             box = r['predicted_element']
             needs_reload = r['needs_reload']
         else:
-            log.error(r['message'])
+            log.error(r.get('message', 'No error msg received'))
         return box, needs_reload
 
 
